@@ -14,7 +14,7 @@
 #include <KLanguageName>
 #include <KStandardAction>
 #include <KStandardShortcut>
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 #include <KActionCollection>
 #include <KToggleAction>
 #include <KToggleFullScreenAction>
@@ -206,7 +206,7 @@ void TopLevel::playSound(const QString &ref)
 // Read options from preferences file
 void TopLevel::readOptions(QString &board, QString &language)
 {
-  KConfigGroup config(KSharedConfig::openConfig(), "General");
+  KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
 
   QString option = config.readEntry("Sound",  "on" );
   bool soundEnabled = option.indexOf(QLatin1String( "on" )) == 0;
@@ -244,7 +244,7 @@ void TopLevel::readOptions(QString &board, QString &language)
 // Write options to preferences file
 void TopLevel::writeOptions()
 {
-  KConfigGroup config(KSharedConfig::openConfig(), "General");
+  KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
   config.writeEntry("Sound", actionCollection()->action(QStringLiteral( "speech_no_sound" ))->isChecked() ? "off": "on");
 
   config.writeEntry("Gameboard", playGround->currentGameboard());
@@ -260,11 +260,11 @@ void TopLevel::setupKAction()
   QAction *action;
 
   //Game
-  KStandardGameAction::gameNew(this, SLOT(fileNew()), actionCollection());
-  KStandardGameAction::load(this, SLOT(fileOpen()), actionCollection());
-  KStandardGameAction::save(this, SLOT(fileSave()), actionCollection());
-  KStandardGameAction::print(this, SLOT(filePrint()), actionCollection());
-  KStandardGameAction::quit(qApp, SLOT(quit()), actionCollection());
+  KGameStandardAction::gameNew(this, &TopLevel::fileNew, actionCollection());
+  KGameStandardAction::load(this, &TopLevel::fileOpen, actionCollection());
+  KGameStandardAction::save(this, &TopLevel::fileSave, actionCollection());
+  KGameStandardAction::print(this, &TopLevel::filePrint, actionCollection());
+  KGameStandardAction::quit(qApp, &QApplication::quit, actionCollection());
 
   action = actionCollection()->addAction( QStringLiteral( "game_save_picture" ));
   action->setText(i18n("Save &as Picture..."));
@@ -299,7 +299,7 @@ void TopLevel::setupKAction()
 
   PlaygroundDelegate *playgroundDelegate = new PlaygroundDelegate(playgroundCombo->view());
   playgroundCombo->setItemDelegate(playgroundDelegate);
-  connect(playgroundCombo, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &TopLevel::changeGameboardFromCombo);
+  connect(playgroundCombo, &KComboBox::currentIndexChanged, this, &TopLevel::changeGameboardFromCombo);
   QWidgetAction *widgetAction = new QWidgetAction(this);
   widgetAction->setDefaultWidget(playgroundCombo);
   actionCollection()->addAction( QStringLiteral( "playgroundSelection" ),widgetAction);
@@ -374,10 +374,10 @@ void TopLevel::open(const QUrl &url)
 
 static QStringList extractSuffixesFromQtPattern(const QString &qtPattern)
 {
-  static const QRegularExpression regexp(".*\\((.*)\\)");
+  static const QRegularExpression regexp(QStringLiteral(".*\\((.*)\\)"));
   const QRegularExpressionMatch match = regexp.match(qtPattern);
   if (match.hasMatch()) {
-    QStringList suffixes = match.captured(1).split(" ");
+    QStringList suffixes = match.captured(1).split(QLatin1Char(' '));
     if (!suffixes.isEmpty()) {
       for (QString &suffix : suffixes) {
         suffix = suffix.mid(1); // Remove the * from the start, we want the actual suffix
@@ -388,7 +388,7 @@ static QStringList extractSuffixesFromQtPattern(const QString &qtPattern)
   } else {
     qWarning() << "extractSuffixesFromQtPattern regexp match failed" << qtPattern;
   }
-  return { ".report_bug_please" };
+  return { QStringLiteral(".report_bug_please") };
 }
 
 static QUrl getSaveFileUrl(QWidget *w, const QString &patterns)
@@ -461,7 +461,7 @@ void TopLevel::filePicture()
   QStringList patterns;
   for(const auto &mimeName : imageWriterMimetypes)
   {
-    const QMimeType mime = mimedb.mimeTypeForName(mimeName);
+    const QMimeType mime = mimedb.mimeTypeForName(QString::fromLatin1(mimeName));
     if (mime.isValid())
     {
       QStringList suffixes;
@@ -471,7 +471,7 @@ void TopLevel::filePicture()
       }
 
       // Favor png
-      const QString pattern = i18nc("%1 is mimetype and %2 is the file extensions", "%1 (%2)", mime.comment(), suffixes.join(' '));
+      const QString pattern = i18nc("%1 is mimetype and %2 is the file extensions", "%1 (%2)", mime.comment(), suffixes.join(QLatin1Char(' ')));
       if (mimeName == "image/png")
       {
         patterns.prepend(pattern);
